@@ -85,7 +85,6 @@ typedef struct
 	/* command line parsing */
 	gboolean new_window;
 	gboolean new_document;
-	gchar *geometry;
 	const GtkSourceEncoding *encoding;
 	GInputStream *stdin_stream;
 	GSList *file_list;
@@ -108,7 +107,7 @@ static const GOptionEntry options[] =
 	/* Version */
 	{
 		"version", 'V', 0, G_OPTION_ARG_NONE, NULL,
-		N_("Show the application's version"), NULL
+		N_("Show the application’s version"), NULL
 	},
 
 	/* List available encodings */
@@ -139,13 +138,6 @@ static const GOptionEntry options[] =
 		NULL
 	},
 
-	/* Window geometry */
-	{
-		"geometry", 'g', 0, G_OPTION_ARG_STRING, NULL,
-		N_("Set the size and position of the window (WIDTHxHEIGHT+X+Y)"),
-		N_("GEOMETRY")
-	},
-
 	/* Wait for closing documents */
 	{
 		"wait", 'w', 0, G_OPTION_ARG_NONE, NULL,
@@ -163,7 +155,7 @@ static const GOptionEntry options[] =
 	/* collects file arguments */
 	{
 		G_OPTION_REMAINING, '\0', 0, G_OPTION_ARG_FILENAME_ARRAY, NULL, NULL,
-		N_("[FILE...] [+LINE[:COLUMN]]")
+		N_("[FILE…] [+LINE[:COLUMN]]")
 	},
 
 	{NULL}
@@ -263,7 +255,7 @@ gedit_app_show_help_impl (GeditApp    *app,
 
 	link = GEDIT_APP_GET_CLASS (app)->help_link_id (app, name, link_id);
 
-	ret = gtk_show_uri (gtk_widget_get_screen (GTK_WIDGET (parent)),
+	ret = gtk_show_uri_on_window (GTK_WINDOW (parent),
 	                    link,
 	                    GDK_CURRENT_TIME,
 	                    &error);
@@ -420,7 +412,6 @@ static void
 open_files (GApplication            *application,
 	    gboolean                 new_window,
 	    gboolean                 new_document,
-	    gchar                   *geometry,
 	    gint                     line_position,
 	    gint                     column_position,
 	    const GtkSourceEncoding *encoding,
@@ -446,11 +437,6 @@ open_files (GApplication            *application,
 		gtk_widget_show (GTK_WIDGET (window));
 	}
 
-	if (geometry)
-	{
-		gtk_window_parse_geometry (GTK_WINDOW (window), geometry);
-	}
-
 	if (stdin_stream)
 	{
 		gedit_debug_message (DEBUG_APP, "Load stdin");
@@ -536,7 +522,6 @@ new_document_activated (GSimpleAction *action,
 	open_files (application,
 	            FALSE,
 	            TRUE,
-	            NULL,
 	            0,
 	            0,
 	            NULL,
@@ -899,7 +884,6 @@ gedit_app_activate (GApplication *application)
 	open_files (application,
 	            priv->new_window,
 	            priv->new_document,
-	            priv->geometry,
 	            priv->line_position,
 	            priv->column_position,
 	            priv->encoding,
@@ -915,13 +899,11 @@ clear_options (GeditApp *app)
 
 	priv = gedit_app_get_instance_private (app);
 
-	g_free (priv->geometry);
 	g_clear_object (&priv->stdin_stream);
 	g_slist_free_full (priv->file_list, g_object_unref);
 
 	priv->new_window = FALSE;
 	priv->new_document = FALSE;
-	priv->geometry = NULL;
 	priv->encoding = NULL;
 	priv->file_list = NULL;
 	priv->line_position = 0;
@@ -969,7 +951,6 @@ gedit_app_command_line (GApplication            *application,
 
 	g_variant_dict_lookup (options, "new-window", "b", &priv->new_window);
 	g_variant_dict_lookup (options, "new-document", "b", &priv->new_document);
-	g_variant_dict_lookup (options, "geometry", "s", &priv->geometry);
 
 	if (g_variant_dict_contains (options, "wait"))
 	{
@@ -1110,7 +1091,6 @@ gedit_app_open (GApplication  *application,
 	open_files (application,
 	            FALSE,
 	            FALSE,
-	            NULL,
 	            0,
 	            0,
 	            NULL,
@@ -1732,6 +1712,11 @@ find_extension_point_section (GMenuModel  *model,
 
 			subsection = g_menu_model_get_item_link (model, i, G_MENU_LINK_SECTION);
 
+			if (subsection == NULL)
+			{
+				subsection = model;
+			}
+
 			j_items = g_menu_model_get_n_items (subsection);
 
 			for (j = 0; j < j_items && !section; j++)
