@@ -18,8 +18,8 @@
  * along with this program; if not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifndef __GEDIT_TAB_H__
-#define __GEDIT_TAB_H__
+#ifndef GEDIT_TAB_H
+#define GEDIT_TAB_H
 
 #include <gtksourceview/gtksource.h>
 #include <gedit/gedit-view.h>
@@ -34,9 +34,9 @@ typedef enum
 	GEDIT_TAB_STATE_REVERTING,
 	GEDIT_TAB_STATE_SAVING,
 	GEDIT_TAB_STATE_PRINTING,
-	GEDIT_TAB_STATE_PRINT_PREVIEWING,
+	GEDIT_TAB_STATE_PRINT_PREVIEWING, /* unused, deprecated */
 	GEDIT_TAB_STATE_SHOWING_PRINT_PREVIEW,
-	GEDIT_TAB_STATE_GENERIC_NOT_EDITABLE,
+	GEDIT_TAB_STATE_GENERIC_NOT_EDITABLE, /* unused, deprecated */
 	GEDIT_TAB_STATE_LOADING_ERROR,
 	GEDIT_TAB_STATE_REVERTING_ERROR,
 	GEDIT_TAB_STATE_SAVING_ERROR,
@@ -74,6 +74,6 @@ void		 gedit_tab_set_info_bar			(GeditTab            *tab,
 
 G_END_DECLS
 
-#endif  /* __GEDIT_TAB_H__  */
+#endif  /* GEDIT_TAB_H  */
 
 /* ex:set ts=8 noet: */
