@@ -18,8 +18,8 @@
  * along with this program; if not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifndef __GEDIT_FILE_BROWSER_STORE_H__
-#define __GEDIT_FILE_BROWSER_STORE_H__
+#ifndef GEDIT_FILE_BROWSER_STORE_H
+#define GEDIT_FILE_BROWSER_STORE_H
 
 #include <gtk/gtk.h>
 
@@ -206,5 +206,5 @@ void		 _gedit_file_browser_store_register_type	(GTypeModule
 
 G_END_DECLS
 
-#endif /* __GEDIT_FILE_BROWSER_STORE_H__ */
+#endif /* GEDIT_FILE_BROWSER_STORE_H */
 /* ex:set ts=8 noet: */
