@@ -2369,7 +2369,7 @@ directory_open (GeditFileBrowserWidget *obj,
 
 		uri = g_file_get_uri (location);
 
-		if (!gtk_show_uri (gtk_widget_get_screen (GTK_WIDGET (obj)), uri, GDK_CURRENT_TIME, &error))
+		if (!gtk_show_uri_on_window (GTK_WINDOW (obj), uri, GDK_CURRENT_TIME, &error))
 		{
 			g_signal_emit (obj, signals[ERROR], 0,
 				       GEDIT_FILE_BROWSER_ERROR_OPEN_DIRECTORY,
@@ -2766,7 +2766,7 @@ on_location_entry_activate (GtkEntry               *entry,
 		gchar *display_name, *msg;
 
 		display_name = g_file_get_parse_name (new_root);
-		msg = g_strdup_printf (_("Error when loading '%s': "
+		msg = g_strdup_printf (_("Error when loading “%s”: "
 		                         "No such directory"),
 		                       display_name);
 
