@@ -3,7 +3,7 @@
  * gedit-file-browser-message-get-view.c
  * This file is part of gedit
  *
- * Copyright (C) 2011 - Jesse van den Kieboom
+ * Copyright (C) 2014 - Jesse van den Kieboom
  *
  * gedit is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -28,8 +28,6 @@
 #include "gedit-file-browser-message-get-view.h"
 #include "plugins/filebrowser/gedit-file-browser-view.h"
 
-#define GEDIT_FILE_BROWSER_MESSAGE_GET_VIEW_GET_PRIVATE(object)(G_TYPE_INSTANCE_GET_PRIVATE((object), GEDIT_TYPE_FILE_BROWSER_MESSAGE_GET_VIEW, GeditFileBrowserMessageGetViewPrivate))
-
 enum
 {
 	PROP_0,
@@ -42,7 +40,11 @@ struct _GeditFileBrowserMessageGetViewPrivate
 	GeditFileBrowserView *view;
 };
 
-G_DEFINE_TYPE (GeditFileBrowserMessageGetView, gedit_file_browser_message_get_view, GEDIT_TYPE_MESSAGE)
+G_DEFINE_TYPE_EXTENDED (GeditFileBrowserMessageGetView,
+                        gedit_file_browser_message_get_view,
+                        GEDIT_TYPE_MESSAGE,
+                        0,
+                        G_ADD_PRIVATE (GeditFileBrowserMessageGetView))
 
 static void
 gedit_file_browser_message_get_view_finalize (GObject *obj)
@@ -118,12 +120,10 @@ gedit_file_browser_message_get_view_class_init (GeditFileBrowserMessageGetViewCl
 	                                                      G_PARAM_READWRITE |
 	                                                      G_PARAM_CONSTRUCT |
 	                                                      G_PARAM_STATIC_STRINGS));
-
-	g_type_class_add_private (object_class, sizeof (GeditFileBrowserMessageGetViewPrivate));
 }
 
 static void
 gedit_file_browser_message_get_view_init (GeditFileBrowserMessageGetView *message)
 {
-	message->priv = GEDIT_FILE_BROWSER_MESSAGE_GET_VIEW_GET_PRIVATE (message);
+	message->priv = gedit_file_browser_message_get_view_get_instance_private (message);
 }
